@@ -4,7 +4,7 @@ import imutils
 import numpy as np
 from . import color
 from .draw_lib import draw_text, blit_alpha_img
-from .dnn import 深度學習人臉模型
+#from .dnn import 深度學習人臉模型
 
 
 
@@ -16,7 +16,7 @@ __all__ = [
             '畫圓形', '畫圓形實心', '旋轉影像', '平移影像', '縮放影像',
             '調整亮度', '調整對比', '模糊', '高斯模糊', '灰階轉黑白',
             'Canny邊緣偵測', '畫出文字', '讀取影像PNG', '畫透明圖',
-            '深度學習人臉模型', '畫直線', '畫折線',
+            '畫直線', '畫折線',
             ]
 
 
